#!/bin/bash
# Plot land/sea mask, height of land surface in CMIP5 models.
#
#   last update: 2013-10-23
#   M. Hayasaki (Univ. Tsukuba, Japan)
#
my_name=$PWD/$0
today=`date +"%F %T"`

### List of functions: chk_dir
#source $HOME/bin/function/chk_dir_file
source ./chk_dir_file

### List of functions: 
###   set_area_world
#source $HOME/topo/101_topo_common.sh
source ./101_topo_common.sh

### Constant (invariant) parameters
project=CMIP5
exp_name=historical   # invariant
run=r0i0p0
  var_name_cdf=orog   # variable name in the NetCDF file (orog)

####### BEGIN: Edit parameters for your environment
  ### Base directories of input files
  topo_netcdf_base=$HOME/reanal01/cmip/${project}/${exp_name}/fx/atmos/orog
  mask_netcdf_base=$HOME/reanal01/cmip/${project}/${exp_name}/fx/atmos/sftlf

### output path
#ps_path=$HOME/topo/cmip/ps
#png_path=$HOME/topo/cmip/png
ps_path=$PWD/ps
png_path=$PWD/png
  chk_dir $ps_path $png_path


### List of variables 
model_list=" MRI-CGCM3 MIROC4h MIROC5    MIROC-ESM  GISS-E2-H \
  bcc-csm1-1 CSIRO-Mk3-6-0 HadGEM2-CC MPI-ESM-LR NorESM1-M IPSL-CM5A-LR IPSL-CM5A-MR "
model_list=" MRI-CGCM3  MIROC-ESM "   # TEST
model_list=" MRI-CGCM3 "   # TEST

area_list=" Japan NW_America NE_America N_Europe W_Europe Ural \
    Siberia Mongolia Tibet Indochina Andes "
area_list=" E_Asia Japan Tibet Maritime_cont all_Asia "      # TEST
area_list=" Japan globe all_Asia all_Europe "
area_list=" Japan "      # For Japan (25-48N, 123-147E)

####### END: Edit parameters for your environment

for model in ${model_list} ; do
### sample filename (NetCDF format)
#  topography: orog_fx_MRI-CGCM3_historical_r0i0p0.nc
#  land/sea mask: sftlf_fx_MRI-CGCM3_historical_r0i0p0.nc

##  topo_netcdf=${topo_netcdf_base}/${model}/${run}/orog_fx_${model}_${exp_name}_${run}.nc
##  mask_netcdf=${mask_netcdf_base}/${model}/${run}/sftlf_fx_${model}_${exp_name}_${run}.nc
  topo_netcdf=orog_fx_${model}_${exp_name}_${run}.nc
  mask_netcdf=sftlf_fx_${model}_${exp_name}_${run}.nc

for area in ${area_list} ; do

  # Give $area,
  # return $lon_range, $lat_range
  set_area_world  ${area}

### Set three flags for plotting/non-plotting height values ($val_on), 
### contour ($con_on), and coast line ($map_on).
### Set label intervals on lat/lon axis ($xlint, $ylint)
case $area in
globe)    # global plot
  val_on=1   # 1: false
  con_on=1   # 1: false
  map_on=1   # 1: false
  xlint=60
  ylint=30
  ;;
all_*|E_Asia|W_Europe)
  val_on=1   # 1: false
  con_on=0   # 0: true
  map_on=0   # 0: true
  xlint=20
  ylint=10
  ;;
*)    # Other area
  val_on=0   # 0: true
  con_on=1   # 0: true, 1: false
  map_on=0   # 0: true
  xlint=5
  ylint=5
  ;;
esac

epsfile=${ps_path}/combi_topo_lsmask_${project}_${model}_${area}.ps
pngfile=${png_path}/`basename $epsfile .ps`.png
pdffile=${ps_path}/`basename $epsfile .ps`.pdf

tmp_gs=t.gs
cat > ${tmp_gs} << EOF
*
* Model topography using CMIP5 models
* (Copied from "topo_JRA_world.sh", JRA topography plot script)
*							2013-10-11
'reinit'
'sdfopen ${topo_netcdf}'
'sdfopen ${mask_netcdf}'
'set display color white'
'c'
*
*** Queue: Get a number of lat/lon grids
'q dims'
*say result
lon_line=sublin(result,2)
lat_line=sublin(result,3)
*
prompt lon_line
*
xdim=subwrd(lon_line,13)-1
ydim=subwrd(lat_line,13)
*
*
'set vpage 0.5 10.0 0.5 8.0'
'set grads off'
*
'set lat ${lat_range}'
'set lon ${lon_range}'
AREA=${area}
EPSFILE="${epsfile}"
*
*'set lat -90 90'
*'set lon -180 180 '
*'set mproj robinson'
*
'set mpdset mres'
'set map  2  1  8'
*
*** Coast line control
if ( ${map_on} = 1 )
'set mpdraw off'
endif
'set poli off'
** Axis label, its intervals
'set ylopts  1  5  0.16'
'set xlopts  1  5  0.16'
'set xlint ${xlint}'
'set ylint ${ylint}'
*
***** Case: "smooth" plot
**'set csmooth on'
***** Case: "tile" plot
'set csmooth off'
*
*** Color palette of topography (shade plot)
'set gxout shaded'
'set black -100 0'
'set rgb  40  187  228  146'
'set rgb  41  255  220  185'
'set rgb  42  243  202  137'
'set rgb  43  230  184   88'
'set rgb  44  217  166   39'
'set rgb  45  168  154   31'
'set rgb  46  162  134   19'
'set rgb  47  156  113    7'
'set rgb  48  183  147  147'
**'set rgb  49  230  230  230'
'set rgb  49  180  180  180'
'set clevs    500   1000   1500   2000  2500  3000  3500  4000  4500  5000'
'set ccols  0    40     41      42    43    44   45    46    47    48    49     10'
*
*** "tile" plot
'set gxout grfill'
'd ${var_name_cdf}'
'draw title Topography & land/sea mask, ${model} in ${project}'
'run cbarn.gs'
*
*
*** contour plot (if you want)
if ( $con_on = 0 )
'set gxout contour'
'set black -100 10'
'set ccolor 1'
'set cint 250'
'set cthick 1'
'set clskip 4'
'd ${var_name_cdf}'
*
'set black -100 10'
'set ccolor 1'
'set cint 1000'
'set cthick 2'
'set clskip 1'
'd ${var_name_cdf}'
endif
*
*** Data values (if you want)
val_on=${val_on}
if ( val_on = 0 )
*** plot elevation value in a grid
'set gxout grid'
'set ccolor 1'
'd ${var_name_cdf}'
endif
*
**** Paint ocean grid cell (land cover ratio >= 0.5)
'set csmooth off'
*'set dfile 2'
'set gxout grfill'
'set rgb 81 230  80  80'
'set rgb 82  80 165 245'
'set clevs     50     100'
'set ccols  82     81'
'd maskout(sftlf.2, 50-sftlf.2)'
*'d sftlf.2'
*
*** Append supplemental info. & figure headers
'set vpage off'
'set string 1 bl' 
'set strsiz 0.12'
'set font 0'
if ( $con_on = 0 )
'draw string 0.3 8.3 contour : 250m int.'
endif
'draw string 0.3 8.0 Horizontal grids = 'xdim'*'ydim
'set string 1 br' 
'set strsiz 0.08'
'draw string 10.3 0.4 ${today}'
'draw string 10.3 0.2 ${my_name}'
*
*** Print section
'enable print t.gx'
'print'
'disable print'
'!gxeps -c -i t.gx -o 'EPSFILE
'quit'
EOF

echo -e "\t *** Model = ${model}; area = ${area} ***"
grads -blc "run ${tmp_gs}" > /dev/null
### for debug
#grads -blc "run ${tmp_gs}"
#less ${tmp_gs}

### Make PNG file (for making PPT)
convert -density 100x100 -rotate 90 $epsfile $pngfile
#convert -density 600x600            $epsfile $pdffile

### Clean-up temporary files
\rm -f ${tmp_gs} t.gx
\rm -f $epsfile

echo "PNG: $pngfile"

done  # area
done  # model

exit

